<?php

namespace Drupal\lb_plus\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Block\BlockManagerInterface;
use Symfony\Component\HttpFoundation\Request;
use Drupal\layout_builder\SectionStorageInterface;
use Drupal\lb_plus\LayoutBuilderPlusSettingsTrait;
use Drupal\layout_builder\Controller\LayoutRebuildTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for Layout Builder Plus routes.
 */
class ChooseBlock extends ControllerBase {

  use LayoutRebuildTrait;
  use LayoutBuilderPlusSettingsTrait;

  protected BlockManagerInterface $blockManager;

  public function __construct(BlockManagerInterface $block_manager) {
    $this->blockManager = $block_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.block'),
    );
  }

  /**
   * Builds the response.
   */
  public function chooseBlockDialog(Request $request, string $section_storage_type, SectionStorageInterface $section_storage) {
    $block_definitions = $this->blockManager->getDefinitions();
    $promoted_block_ids = $this->getLbPlusSetting($section_storage, 'promoted_blocks') ?? [];
    $blocks_config = $this->getLbPlusSetting($section_storage, 'block_config') ?? [];
    $path = $this->moduleHandler()->getModule('lb_plus')->getPath();

    $blocks = [];
    foreach ($promoted_block_ids as $promoted_block_id) {
      $promoted_block_definition = $block_definitions[$promoted_block_id];
      $icon_path = $blocks_config['icon'][$promoted_block_id] ?? '/' . $path . '/assets/default-block-icon.svg';
      $blocks[] = [
        '#type' => 'container',
        '#attributes' => [
          'id' => $promoted_block_id,
          'class' => ['draggable-block'],
          'draggable' => 'true',
        ],
        'icon' => [
          '#type' => 'container',
          '#attributes' => [
            'class' => ['draggable-block-image'],
            'style' => ["background-image: url('$icon_path');"],
          ],
        ],
        'label' => ['#markup' => "<div class='draggable-block-label'>{$promoted_block_definition['admin_label']}</div>"],
      ];
    }

    $build['content'] = [
      '#type' => 'container',
      '#attributes' => ['id' => 'lb-plus-add-block-container'],
      'blocks' => $blocks,
    ];

    return $build;
  }

}
